========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/blazar-nova.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

============
blazar-nova
============

This package contains the Blazar filter - a Nova scheduler filter used for the
host reservation feature.

Other Resources
---------------

* Source code:

    * `Blazar <https://opendev.org/openstack/blazar>`__
    * `Nova scheduler filter <https://opendev.org/openstack/blazar-nova>`__
    * `Client tools <https://opendev.org/openstack/python-blazarclient>`__
    * `Dashboard (Horizon plugin) <https://opendev.org/openstack/blazar-dashboard>`__

* Blueprints/Bugs: https://launchpad.net/blazar
* Documentation: https://docs.openstack.org/blazar/latest/
